# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pygooglenews']

package_data = \
{'': ['*']}

install_requires = \
['beautifulsoup4>=4.9.1,<5.0.0',
 'dateparser>=0.7.6,<0.8.0',
 'feedparser>=5.2.1,<6.0.0',
 'requests>=2.24.0,<3.0.0']

setup_kwargs = {
    'name': 'pygooglenews',
    'version': '0.1.1',
    'description': 'If Google News had a Python library',
    'long_description': '# pygooglenews\nIf Google News had a Python library\n\n\nCreated by Artem from [newscatcherapi.com](https://newscatcherapi.com/) but you do not need anything from us or from anyone else to get the software going, it just works out of the box.\n\nMy [blog post about how I did it](https://codarium.substack.com/p/reverse-engineering-google-news-rss)\n\n## Demo\n\n![](pygooglenews-demo.gif)\n\nYou might also like to check our [Google News API](https://rapidapi.com/newscatcher-api-newscatcher-api-default/api/google-news?endpoint=apiendpoint_5e0fa919-2494-4b20-a212-d186b7e8c3d8) or [Financial Google News API](https://rapidapi.com/newscatcher-api-newscatcher-api-default/api/stock-google-news?endpoint=apiendpoint_c70050d2-34ac-4eac-a1b2-09aefb19d1a5)\n\n### Table of Contents\n- [About](#about)\n- [Examples of Use Cases](#usecase)\n- [Working with Google News in Production](#production)\n- [Motivation](#motivation)\n- [Installation](#installation)\n- [Quickstart](#quickstart)\n- [Documentation](#documentation)\n- [Advanced Query Search Examples](#examples)\n- [About me](#aboutme)\n\n<a name="about"/>\n\n## **About**\n\nA python wrapper of the Google News RSS feed.\n\nTop stories, topic related news feeds, geolocation news feed, and an extensive full text search feed.\n\nThis work is more of a collection of all things I could find out about how Google News functions.\n\n### **How is it different from other Pythonic Google News libraries?**\n\n1. URL-escaping user input helper for the search function\n2. Extensive support for the search function that makes it simple to use:\n    - exact match\n    - in title match, in url match, etc\n    - search by date range (`from_` & `to_`), latest published (`when`)\n3. Parsing of the sub articles. Almost always, all feeds except the search one contain a subset of similar news for each article in a feed. This package takes care of extracting those sub articles. This feature might be highly useful to ML task when you need to collect a data of similar article headlines\n\n<a name="usecase"/>\n\n## Examples of Use Cases\n\n1. Integrating a news feed to your platform/application/website\n2. Collecting data by topic to train your own ML model\n3. Search for latest mentions for your new product\n4. Media monitoring of people/organizations — PR\n\n\n<a name="production"/>\n\n## Working with Google News in Production\n\nBefore we start, if you want to integrate Google News data to your production then I would advise you to use one of the 3 methods described below. Why? Because you do not want your servers IP address to be locked by Google. Every time you call any function there is an HTTPS request to Google\'s servers. **Don\'t get me wrong, this Python package still works out of the box.**\n\n1. NewsCatcher\'s [Google News API](https://rapidapi.com/newscatcher-api-newscatcher-api-default/api/google-news?endpoint=apiendpoint_5e0fa919-2494-4b20-a212-d186b7e8c3d8) — all code is written for you, clean & structured JSON output. Low price. You can test it yourself with no credit card. Plus, [financial version of API](https://rapidapi.com/newscatcher-api-newscatcher-api-default/api/stock-google-news?endpoint=apiendpoint_c70050d2-34ac-4eac-a1b2-09aefb19d1a5) is also available.\n2. [ScrapingBee API](https://www.scrapingbee.com?fpr=artem26) which handles proxy rotation for you. Each function in this package has `scraping_bee` parameter where you paste your API key. You can also try it for free, no credit card required. See [example](#scrapingbeeexample)\n3. Your own proxy — already have a pool of proxies? Each function in this package has `proxies` parameter (python dictionary) where you just paste your own proxies. \n\n<a name="motivaion"/>\n\n## **Motivation**\n\nI love working with the news data. I love it so much that I created\xa0[my own company that crawls for hundreds of thousands of news articles, and allow you to search it via a news API](https://newscatcherapi.com/). But this time, I want to share with the community a Python package that makes it simple to get the news data from the best search engine ever created -\xa0[Google](https://news.google.com/).\n\nMost likely, you know already that Google has its own\xa0[news service](https://news.google.com/). It is different from the usual Google search that we use on a daily basis (sorry\xa0[DuckDuckGo](https://duckduckgo.com/), maybe next time).\n\n**This package uses the RSS feed of the Google News. The\xa0[top stories page](https://news.google.com/rss), for example.**\n\nRSS is an XML page that is already well structured. I heavily rely on Feedparser package to parse the RSS feed.\n\nGoogle News used to have an API but it was deprecated many years ago. (Unofficial) information \nabout RSS syntax is decentralized over the web. There is no official documentation. So, I tried my best\nto collect all this informaion in one place. \n\n\n<a name="installation"/>\n\n## **Installation**\n\n```shell script\n$ pip install pygooglenews\n\n```\n\n<a name="quickstart"/>\n\n## **Quickstart**\n\n```python\nfrom pygooglenews import GoogleNews\n\ngn = GoogleNews()\n\n```\n\n### **Top Stories**\n\n```python\ntop = gn.top_news()\n```\n\n### **Stories by Topic**\n\n```python\nbusiness = gn.topic_headlines(\'business\')\n\n```\n\n### **Geolocation Specific Stories**\n\n```python\nheadquaters = gn.geo_headlines(\'San Fran\')\n\n```\n\n### **Stories by a Query Search**\n\n```python\n# search for the best matching articles that mention MSFT and \n# do not mention AAPL (over the past 6 month\nsearch = gn.search(\'MSFT -APPL\', when = \'6m\')\n\n```\n\n---\n<a name="documentation"/>\n\n## **Documentation - Functions & Classes**\n\n### **GoogleNews Class**\n\n```python\nfrom pygooglenews import GoogleNews\n# default GoogleNews instance\ngn = GoogleNews(lang = \'en\', country = \'US\')\n\n```\n\nTo get the access to all the functions, you first have to initiate the\xa0`GoogleNews`\xa0class.\n\nIt has 2 required variables:\xa0`lang`\xa0and\xa0`country`\n\nYou can try any combination of those 2, however, it does not exist for all. Only the combinations that are supported by GoogleNews will work. Check the official Google News page to check what is covered:\n\nOn the bottom left side of the Google News page you may find a\xa0`Language & region`\xa0section where you can find all of the supported combinations.\n\n\nFor example, for\xa0`country=UA`\xa0(Ukraine), there are 2 languages supported:\n\n- `lang=uk`\xa0Ukrainian\n- `lang=ru`\xa0Russian\n\n---\n\n### **Top Stories**\n\n```python\ntop = gn.top_news(proxies=None, scraping_bee = None)\n\n```\n\n`top_news()`\xa0returns the top stories for the selected country and language that are defined in\xa0`GoogleNews`\xa0class. The returned object contains `feed` (FeedParserDict) and `entries` list of articles found with all data parsed.\n\n---\n\n### **Stories by Topic**\n\n```python\nbusiness = gn.topic_headlines(\'BUSINESS\', proxies=None, scraping_bee = None)\n\n```\n\nThe returned object contains `feed` (FeedParserDict) and `entries` list of articles found with all data parsed.\n\nAccepted topics are:\n\n- `WORLD`\n- `NATION`\n- `BUSINESS`\n- `TECHNOLOGY`\n- `ENTERTAINMENT`\n- `SCIENCE`\n- `SPORTS`\n- `HEALTH`\n\nHowever, you can find some other topics that are also supported by Google News.\n\nFor example, if you search for\xa0`corona`\xa0in the search tab of\xa0`en`\xa0+\xa0`US`\xa0you will find\xa0`COVID-19`\xa0as a topic.\n\nThe URL looks like this:\xa0`https://news.google.com/topics/CAAqIggKIhxDQkFTRHdvSkwyMHZNREZqY0hsNUVnSmxiaWdBUAE?hl=en-US&gl=US&ceid=US%3Aen`\n\nWe have to copy the text after\xa0`topics/`\xa0and before\xa0`?`, then you can use it as an input for the\xa0`top_news()`\xa0function.\n\n```python\nfrom pygooglenews import GoogleNews\n\ngn = GoogleNews()\ncovid = gn.topic_headlines(\'CAAqIggKIhxDQkFTRHdvSkwyMHZNREZqY0hsNUVnSmxiaWdBUAE\')\n\n```\n\n**However, be aware that this topic will be unique for each language/country combination.**\n\n---\n\n### **Stories by Geolocation**\n\n```python\ngn = GoogleNews(\'uk\', \'UA\')\nkyiv = gn.geo_headlines(\'kyiv\', proxies=None, scraping_bee = None)\n# or \nkyiv = gn.geo_headlines(\'kiev\', proxies=None, scraping_bee = None)\n# or\nkyiv = gn.geo_headlines(\'киев\', proxies=None, scraping_bee = None)\n# or\nkyiv = gn.geo_headlines(\'Київ\', proxies=None, scraping_bee = None)\n\n```\n\nThe returned object contains `feed` (FeedParserDict) and `entries` list of articles found with all data parsed.\n\nAll of the above variations will return the same feed of the latest news about Kyiv, Ukraine:\n\n```python\ngeo[\'feed\'].title\n\n# \'Київ - Останні - Google Новини\'\n\n```\n\nIt is language agnostic, however, it does not guarantee that the feed for any specific place will exist. For example, if you want to find the feed on\xa0`LA`\xa0or\xa0`Los Angeles`\xa0you can do it with\xa0`GoogleNews(\'en\', \'US\')`.\n\nThe main (`en`,\xa0`US`) Google News client will most likely find the feed about the most places.\n\n---\n\n### **Stories by a Query**\n\n```python\ngn.search(query: str, helper = True, when = None, from_ = None, to_ = None, proxies=None, scraping_bee=None)\n\n```\n\nThe returned object contains `feed` (FeedParserDict) and `entries` list of articles found with all data parsed.\n\nGoogle News search itself is a complex function that has inherited some features from the standard Google Search.\n\n[The official reference on what could be inserted](https://developers.google.com/custom-search/docs/xml_results)\n\nThe biggest obstacle that you might have is to write the URL-escaping input. To ease this process,\xa0`helper = True`\xa0is turned on by default.\n\n`helper`\xa0uses\xa0`urllib.parse.quote_plus`\xa0to automatically convert the input.\n\nFor example:\n\n- `\'New York metro opening\'`\xa0-->\xa0`\'New+York+metro+opening\'`\n- `\'AAPL -MSFT\'`\xa0-->\xa0`\'AAPL+-MSFT\'`\n- `\'"Tokyo Olimpics date changes"\'`\xa0-->\xa0`\'%22Tokyo+Olimpics+date+changes%22\'`\n\nYou can turn it off and write your own query in case you need it by\xa0`helper = False`\n\n`when`\xa0parameter (`str`) sets the time range for the published datetime. I could not find any documentation regarding this option, but here is what I deducted:\n\n- `h`\xa0for hours.(For me, worked for up to\xa0`101h`).\xa0`when=12h`\xa0will search for only the articles matching the\xa0`search`\xa0criteri and published for the last 12 hours\n- `d`\xa0for days\n- `m`\xa0for month (For me, worked for up to\xa0`48m`)\n\nI did not set any hard limit here. You may try put here anything. Probably, it will work. However, I would like to warn you that wrong inputs will not lead to an error. Instead, the\xa0`when`\xa0parameter will be ignored by the Google.\n\n`from_` and `to_` accept the following format of date: `%Y-%m-%d` For example, `2020-07-01` \n\n---\n\n**[Google\'s Special Query Terms](https://developers.google.com/custom-search/docs/xml_results#special-query-terms)\xa0Cheat Sheet**\n\nMany Google\'s Special Query Terms have been tested one by one. Most of the core ones have been inherited by Google News service. At first, I wanted to integrate all of those as the\xa0`search()`\xa0function parameters. But, I realised that it might be a bit confusing and difficult to make them all work correctly.\n\nInstead,\xa0**I decided to write some kind of a cheat sheet that should give you a decent understanding of what you could do**.\n\n* Boolean OR Search [ OR ]\n\n```python\nfrom pygooglenews import GoogleNews\n\ngn = GoogleNews()\n\ns = gn.search(\'boeing OR airbus\')\n\nprint(s[\'feed\'].title)\n# "boeing OR airbus" - Google News\n\n```\n\n* Exclude Query Term [-]\n\n"The exclude (`-`) query term restricts results for a particular search request to documents that do not contain a particular word or phrase. To use the exclude query term, you would preface the word or phrase to be excluded from the matching documents with "-" (a minus sign)."\n\n* Include Query Term [+]\n\n"The include (`+`) query term specifies that a word or phrase must occur in all documents included in the search results. To use the include query term, you would preface the word or phrase that must be included in all search results with "+" (a plus sign).\n\nThe URL-escaped version of\xa0**`+`**\xa0(a plus sign) is\xa0`%2B`."\n\n\n* Phrase Search\n\n"The phrase search (`"`) query term allows you to search for complete phrases by enclosing the phrases in quotation marks or by connecting them with hyphens.\n\nThe URL-escaped version of\xa0**`"`**\xa0(a quotation mark) is\xa0**`%22`**.\n\nPhrase searches are particularly useful if you are searching for famous quotes or proper names."\n\n* allintext\n\n"The\xa0**`allintext:`**\xa0query term requires each document in the search results to contain all of the words in the search query in the body of the document. The query should be formatted as\xa0**`allintext:`**\xa0followed by the words in your search query.\n\nIf your search query includes the\xa0**`allintext:`**\xa0query term, Google will only check the body text of documents for the words in your search query, ignoring links in those documents, document titles and document URLs."\n\n* intitle\n\n"The `intitle:` query term restricts search results to documents that contain a particular word in the document title. The search query should be formatted as `intitle:WORD` with no space between the intitle: query term and the following word."\n\n* allintitle\n\n"The\xa0**`allintitle:`**\xa0query term restricts search results to documents that contain all of the query words in the document title. To use the\xa0**`allintitle:`**\xa0query term, include "allintitle:" at the start of your search query.\n\nNote:\xa0Putting\xa0**`allintitle:`**\xa0at the beginning of a search query is equivalent to putting\xa0[intitle:](https://developers.google.com/custom-search/docs/xml_results#TitleSearchqt)\xa0in front of each word in the search query."\n\n* inurl\n\n"The `inurl:` query term restricts search results to documents that contain a particular word in the document URL. The search query should be formatted as `inurl:WORD` with no space between the inurl: query term and the following word"\n\n* allinurl\n\nThe `allinurl:` query term restricts search results to documents that contain all of the query words in the document URL. To use the `allinurl:` query term, include allinurl: at the start of your search query.\n\n\n### List of operators that do not work (for me, at least):\n\n1. Most (probably all) of the\xa0`as_*`\xa0terms do not work for Google News\n2. `allinlinks:`\n3. `related:`\n\n\n**Tip**. If you want to build a near real-time feed for a specific topic, use\xa0`when=\'1h\'`. If Google captured fewer than 100 articles over the past hour, you should be able to retrieve all of them.\n\nCheck the\xa0[Useful Links](notion://www.notion.so/Google-News-API-Documentation-b95117b9ecd94076bb1d8cf7c2957d78#useful-links)\xa0section if you want to dig into how Google Search works.\n\nEspecially,\xa0[Special Query Terms](https://developers.google.com/custom-search/docs/xml_results#special-query-terms)\xa0section of Google XML reference.\n\nPlus, I will provide some more examples under the\xa0[Full-Text Search Examples](notion://www.notion.so/Google-News-API-Documentation-b95117b9ecd94076bb1d8cf7c2957d78#examples)\xa0section\n\n---\n\n### **Output Body**\n\nAll 4 functions return the\xa0`dictionary`\xa0that has 2 sub-objects:\n\n- `feed`\xa0- contains the information on the feed metadata\n- `entries`\xa0- contains the parsed articles\n\nBoth are inherited from the\xa0[Feedparser](https://github.com/kurtmckee/feedparser). The only change is that each dictionary under\xa0`entries`\xa0also contains\xa0`sub_articles`\xa0which are the similar articles found in the description. Usually, it is non-empty for\xa0`top_news()`\xa0and\xa0`topic_headlines()`\xa0feeds.\n\n**Tip**\xa0To check what is the found feed\'s name just check the\xa0`title`\xa0under the\xa0`feed`\xa0dictionary\n\n---\n<a name="scrapingbeeexample"/>\n\n## How to use pygooglenews with [ScrapingBee](https://www.scrapingbee.com?fpr=artem26)\n\nEvery function has `scrapingbee` parameter. It accepts your [ScrapingBee](https://www.scrapingbee.com?fpr=artem26) API key that will be used to get the response from Google\'s servers. \n\nYou can take a look at what exactly is happening in the source code: check for `__scaping_bee_request()` function under GoogleNews class\n\nPay attention to the concurrency of each plan at [ScrapingBee](https://www.scrapingbee.com?fpr=artem26)\n \nHow to use example:\n\n```python\ngn = GoogleNews()\n\n# it\'s a fake API key, do not try to use it\ngn.top_news(scraping_bee = \'I5SYNPRFZI41WHVQWWUT0GNXFMO104343E7CXFIISR01E2V8ETSMXMJFK1XNKM7FDEEPUPRM0FYAHFF5\')\n```\n\n---\n\n## How to use pygooglenews with proxies\n\nSo, if you have your own HTTP/HTTPS proxy(s) that you want to use to make requests to Google, that\'s how you do it:\n\n```python\ngn = GoogleNews()\n\ngn.top_news(proxies = {\'https\':\'34.91.135.38:80\'})\n```\n\n---\n<a name="examples"/>\n\n## **Advanced Querying Search Examples**\n\n### **Example 1. Search for articles that mention\xa0`boeing`\xa0and do not mention\xa0`airbus`**\n\n```python\nfrom pygooglenews import GoogleNews\n\ngn = GoogleNews()\n\ns = gn.search(\'boeing -airbus\')\n\nprint(s[\'feed\'].title)\n# "boeing -airbus" - Google News\n\n```\n\n### **Example 2. Search for articles that mention\xa0`boeing`\xa0in title**\n\n```python\nfrom pygooglenews import GoogleNews\n\ngn = GoogleNews()\n\ns = gn.search(\'intitle:boeing\')\n\nprint(s[\'feed\'].title)\n# "intitle:boeing" - Google News\n\n```\n\n### **Example 3. Search for articles that mention\xa0`boeing`\xa0in title and got published over the past hour**\n\n```python\nfrom pygooglenews import GoogleNews\n\ngn = GoogleNews()\n\ns = gn.search(\'intitle:boeing\', when = \'1h\')\n\nprint(s[\'feed\'].title)\n# "intitle:boeing when:1h" - Google News\n\n```\n\n### **Example 4. Search for articles that mention\xa0`boeing`\xa0or\xa0`airbus`**\n\n```python\nfrom pygooglenews import GoogleNews\n\ngn = GoogleNews()\n\ns = gn.search(\'boeing OR airbus\', when = \'1h\')\n\nprint(s[\'feed\'].title)\n# "boeing AND airbus when:1h" - Google News\n\n```\n\n---\n<a name="useful-links"/>\n\n## **Useful Links**\n\n[Stack Overflow thread from which it all began](https://stackoverflow.com/questions/51537063/url-format-for-google-news-rss-feed)\n\n[Google XML reference for the search query](https://developers.google.com/custom-search/docs/xml_results)\n\n[Google News Search parameters (The Missing Manual)](http://web.archive.org/web/20150204025359/http://blog.slashpoundbang.com/post/12975232033/google-news-search-parameters-the-missing-manual)\n\n---\n<a name="built"/>\n\n## **Built With**\n\n[Feedparser](https://github.com/kurtmckee/feedparser)\n\n[Beutifulsoup4](https://pypi.org/project/beautifulsoup4/)\n\n---\n<a name="aboutme"/>\n\n## **About me**\n\nMy name is Artem. I ❤️ working with news data. I am a co-founder of [NewsCatcherAPI](https://newscatcherapi.com/) - **Ultra-fast API to find news articles by any topic, country, language, website, or keyword**\n\nIf you are interested in hiring me, please, contact me by email -\xa0**bugara.artem@gmail.com** or **artem@newscatcherapi.com**\n\nFollow me on 🖋\xa0[Twitter](https://twitter.com/bugaralife)\xa0- I write about data engineering, python, entrepreneurship, and memes.\n\nWant to read about how it all was done? Subscribe to [CODARIUM](https://codarium.substack.com/)\n\nthx to Kizy\n',
    'author': 'kotartemiy',
    'author_email': 'bugara.artem@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://www.newscatcherapi.com',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
